"""
Module containing objects associated with the Standard European Vector Architecture

Refer to http://seva-plasmids.com/

"""
MARKER_DICT = {
    "1": "Ampicillin",
    "2": "Kanamycin",
    "3": "Chloramphenicol",
    "4": "Streptomycin/Spectinomycin",
    "5": "Tetracycline",
    "6": "Gentamicin",
}
ORI_DICT = {
    "2": "RK2",
    "3": "pBBR1",
    "4": "pRO1600/ColE1",
    "5": "RSF1010",
    "6": "p15A",
    "7": "pSC101",
    "8": "pUC",
    "9": "pBR322-ROP",
}
